use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Brocard
Data
ELPENGUIN
Etheridge
James
Karen
Lapworth
Laver
Leo
Léon
Page
acme
elpenguin
ether
irc
lib
listref
llap
